"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const WebpackDevMiddleware = require("webpack-dev-middleware");
const WebpackHotMiddleware = require("webpack-hot-middleware");
/**
 * WebpackDevServerPlugin provides access to the Webpack development server.
 */
const WebpackDevServerPlugin = {
    name: "WebpackDevServerPlugin",
    register: async (server, options) => {
        const webpackDevMiddleware = WebpackDevMiddleware(options.compiler, options.devMiddlewareOptions);
        const webpackHotMiddleware = WebpackHotMiddleware(options.compiler, {
            path: "/__webpack_hmr",
        });
        server.ext("onRequest", async (request, h) => {
            try {
                await webpackDevMiddleware(request.raw.req, request.raw.res, (err) => {
                    // webpack-dev-middleware never calls the callback with an err object.
                    // See node_modules/webpack-dev-middleware/lib/middleware.js.
                });
                // Hapi doesn't seem to honor h.abandon, leading to "headers already sent"
                // errors on the console. Mark the private property _isReplied as true so
                // that Hapi doesn't send anything.
                // https://github.com/hapijs/hapi/issues/3884
                request._isReplied = request.raw.res.finished;
                return request.raw.res.finished ? h.abandon : h.continue;
            }
            catch (err) {
                return err;
            }
        });
        server.ext("onRequest", async (request, h) => {
            try {
                await new Promise((resolve, reject) => {
                    webpackHotMiddleware(request.raw.req, request.raw.res, (err) => {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve();
                        }
                    });
                });
                request._isReplied = request.raw.res.finished;
                return request.raw.res.finished ? h.abandon : h.continue;
            }
            catch (err) {
                return err;
            }
        });
        server.expose("devMiddleware", webpackDevMiddleware);
    },
};
exports.default = WebpackDevServerPlugin;
//# sourceMappingURL=WebpackDevServerPlugin.js.map